// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <cassert>

#include "globals.hh"
#include "entrance.hh"

CL_Surface* Entrance::surface;

Entrance::Entrance(int x, int y)
{
  last_release = 0;
  x_pos = x;
  y_pos = y;
}

Entrance::Entrance(entrance_data data)
{
  x_pos = data.x_pos;
  y_pos = data.y_pos;
  release_rate = data.release_rate;
  last_release = 0;
}

bool
Entrance::pingu_ready()
{
  if (last_release + 3000 > CL_System::get_time()) {
    return false;
  } else {
    last_release = CL_System::get_time();
    return true;
  }
}

Pingu*
Entrance::get_pingu()
{
  if (sound_enabled) {
    CL_SoundBuffer *soundbuffer = CL_Sample::create("../data/sounds/OING.WAV", NULL);
    soundbuffer->play();
  }

  return new Pingu(x_pos, y_pos);
}

void
Entrance::draw()
{
  surface->put_screen(x_pos-32, y_pos-16);
}

void
Entrance::draw_offset(int x, int y)
{
  surface->put_screen(x_pos-32 + x, y_pos-16 + y);
}

void 
Entrance::load_data(CL_ResourceManager* resource)
{
  surface = CL_Res_Surface::load("Game/entrance", *resource);
  assert(surface);
}

/* EOF */
